==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V2beta1ExternalMetricSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import io.kubernetes.client.custom.Quantity;
import java.lang.String;
import java.lang.Boolean;

public interface V2beta1ExternalMetricSourceFluent<A extends V2beta1ExternalMetricSourceFluent<A>> extends Fluent<A>{


    public String getMetricName();
    public A withMetricName(String metricName);
    public Boolean hasMetricName();
    
/**
 * This method has been deprecated, please use method buildMetricSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getMetricSelector();
    public V1LabelSelector buildMetricSelector();
    public A withMetricSelector(V1LabelSelector metricSelector);
    public Boolean hasMetricSelector();
    public V2beta1ExternalMetricSourceFluent.MetricSelectorNested<A> withNewMetricSelector();
    public V2beta1ExternalMetricSourceFluent.MetricSelectorNested<A> withNewMetricSelectorLike(V1LabelSelector item);
    public V2beta1ExternalMetricSourceFluent.MetricSelectorNested<A> editMetricSelector();
    public V2beta1ExternalMetricSourceFluent.MetricSelectorNested<A> editOrNewMetricSelector();
    public V2beta1ExternalMetricSourceFluent.MetricSelectorNested<A> editOrNewMetricSelectorLike(V1LabelSelector item);
    public Quantity getTargetAverageValue();
    public A withTargetAverageValue(Quantity targetAverageValue);
    public Boolean hasTargetAverageValue();
    public Quantity getTargetValue();
    public A withTargetValue(Quantity targetValue);
    public Boolean hasTargetValue();

    public interface MetricSelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V2beta1ExternalMetricSourceFluent.MetricSelectorNested<N>>{

        
    public N and();    public N endMetricSelector();
}


}

==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V2beta1ExternalMetricSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import io.kubernetes.client.custom.Quantity;
import java.lang.String;
import java.lang.Boolean;

public interface V2beta1ExternalMetricSourceFluent<A extends V2beta1ExternalMetricSourceFluent<A>> extends Fluent<A>{


    public String getMetricName();
    public A withMetricName(String metricName);
    public Boolean hasMetricName();
    
/**
 * This method has been deprecated, please use method buildMetricSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getMetricSelector();
    public V1LabelSelector buildMetricSelector();
    public A withMetricSelector(V1LabelSelector metricSelector);
    public Boolean hasMetricSelector();
    public V2beta1ExternalMetricSourceFluent.MetricSelectorNested<A> withNewMetricSelector();
    public V2beta1ExternalMetricSourceFluent.MetricSelectorNested<A> withNewMetricSelectorLike(V1LabelSelector item);
    public V2beta1ExternalMetricSourceFluent.MetricSelectorNested<A> editMetricSelector();
    public V2beta1ExternalMetricSourceFluent.MetricSelectorNested<A> editOrNewMetricSelector();
    public V2beta1ExternalMetricSourceFluent.MetricSelectorNested<A> editOrNewMetricSelectorLike(V1LabelSelector item);
    public Quantity getTargetAverageValue();
    public A withTargetAverageValue(Quantity targetAverageValue);
    public Boolean hasTargetAverageValue();
    public A withNewTargetAverageValue(final String value);
    public Quantity getTargetValue();
    public A withTargetValue(Quantity targetValue);
    public Boolean hasTargetValue();
    public A withNewTargetValue(final String value);

    public interface MetricSelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V2beta1ExternalMetricSourceFluent.MetricSelectorNested<N>>{

        
    public N and();    public N endMetricSelector();
}


}
